{ pkgs
, lib
, config
, ... }: with lib; let
  cfg = config.passthrough.gnome;
in mkIf cfg.enable {
  dconf.settings = let
    p = "org/gnome";
    pd = "${p}/desktop";
    ps = "${p}/shell";
    pse = "${ps}/extensions";
  in {
    "${pd}/peripherals/mouse".natural-scroll = true;
    "${p}/epiphany".ask-for-default = false;
    "${p}/evolution-data-server".migrated = true;

    "${p}/nautilus/preferences" = {
      default-folder-viewer = "icon-view";
      migrated-gtk-settings = true;
      search-filter-time-type = "last_modified";
    };

    "${pd}/background" = {
      color-shading-type = "solid";
      picture-options = "zoom";
      picture-uri = "file://${./catppuccin-nix.png}";
      picture-uri-dark = "file://${./catppuccin-nix.png}";
      primary-color = "#000000000000";
      secondary-color = "#000000000000";
    };

    "${pd}/interface" = {
      color-scheme = "prefer-dark";
      cursor-theme = "Catppuccin-Frappe-Dark-Cursors";
      font-antialiasing = "grayscale";
      font-hinting = "slight";
      gtk-theme = "Catppuccin-Frappe-Compact-Pink-Dark";
      icon-theme = "Papirus-Dark";
    };

    "${pd}/screensaver" = {
      color-shading-type = "solid";
      picture-options = "zoom";
      picture-uri = "file://${./catppuccin-nix.png}";
      primary-color = "#000000000000";
      secondary-color = "#000000000000";
    };

    "${pd}/wm/preferences" = {
      action-double-click-titlebar = "toggle-maximize";
      action-middle-click-titlebar = "minimize";
      button-layout = "close,minimize,maximize:appmenu";
    };

    "${ps}" = {
      disabled-extensions = [
        "light-style@gnome-shell-extensions.gcampax.github.com"
        "places-menu@gnome-shell-extensions.gcampax.github.com"
        "windowsNavigator@gnome-shell-extensions.gcampax.github.com"
        "window-list@gnome-shell-extensions.gcampax.github.com"
        "dash-to-panel@jderose9.github.com"
      ];
      enabled-extensions = [
        "user-theme@gnome-shell-extensions.gcampax.github.com"
        "apps-menu@gnome-shell-extensions.gcampax.github.com"
        "drive-menu@gnome-shell-extensions.gcampax.github.com"
        "workspace-indicator@gnome-shell-extensions.gcampax.github.com"
        "dash-to-dock@micxgx.gmail.com"
      ];
      welcome-dialog-last-shown-version = "45.3";
    };

    "${pse}/user-theme".name = "Catppuccin-Frappe-Compact-Pink-Dark";

    "${pse}/dash-to-dock" = {
      background-opacity = 0.80000000000000004;
      dash-max-icon-size = 48;
      dock-position = "BOTTOM";
      height-fraction = 0.90000000000000002;
      multi-monitor = true;
    };

    "${pse}/dash-to-panel" = {
      animate-appicon-hover-animation-extent = ''{'RIPPLE': 4, 'PLANK': 4, 'SIMPLE': 1}'';
      appicon-margin = 0;
      appicon-padding = 4;
      available-monitors = [ 0 ];
      dot-position = "BOTTOM";
      hotkeys-overlay-combo = "TEMPORARILY";
      leftbox-padding = -1;
      panel-anchors = ''{"0":"MIDDLE"}'';
      panel-lengths=''{"0":100}'';
      panel-sizes=''{"0":42}'';
      primary-monitor = 0;
      status-icon-padding = -1;
      trans-use-custom-bg = false;
      tray-padding = -1;
      window-preview-title-position = "TOP";
    };
  };
}
